pitchtools.diatonic_pitch_name_to_diatonic_pitch_number
=======================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_name_to_diatonic_pitch_number.diatonic_pitch_name_to_diatonic_pitch_number
